@@ -15,7 +15,7 @@ use Lemonldap::NG::Common::Apache::Session::Serialize::JSON;
 use Lemonldap::NG::Common::Apache::Session::Store;
 use Lemonldap::NG::Common::Apache::Session::Lock;
 
-our $VERSION = '1.9.2';
+our $VERSION = '1.9.3';
 
 sub _load {
     my ( $backend, $func ) = @_;
@@ -338,7 +338,7 @@ sub _LDAPGKFAS {
     );
 
     $ldap->unbind();
-    $ldap->disconect();
+    $ldap->disconnect();
 
     Apache::Session::Store::LDAP->logError($msg) if ( $msg->code );
 
